==> starnet.1.0.tar: hms2rad.f <==
      subroutine hms2rad(str,rad,error)
C
C Description:
C 
C This routine converts a string that specifies a Right Ascension in
C hour, minute, second format to an angle specified in radians.
C
C Programming interface:
C
C Name   In/out  Type           Structure  Meaning
C
C str    in      character*(*)  scalar     The string specifying the angle
C rad    out     real*8         scalar     The angle expressed in radians
C error  out     logical        scalar     TRUE if an error occurs.
C
C Errors:
C 
C If the angle is in a format that cannot be converted, or if the 
C string specification is in a non-standard format, or if the specified
C angle is out of the standard range, then error is
C set TRUE and the routine immediately terminates.
C
C Routines accessed:
C
C err_msg
C fnblnk
C is_fp_num
C is_int_num
C left_justify
C
      implicit none
      include 'std_io.f'
      include 'include_astronet.f'
      real*8 rad,rdum1,rdum2,rdum3
      integer ptr1,ptr2,fnblnk,idum
      logical error,negative,is_fp_num,is_int_num
      character*64 string,substring1,substring2,substring3,
     $     left_justify
      character*(*) str
      rad=0.0d0
      string=str
      ptr1=fnblnk(string)
      if (ptr1 .eq. 0) then
         call err_msg('hms2rad','The RA string is empty.')
         error=.true.
      else
         if (string(ptr1:ptr1) .eq. '-') then
            negative=.true.
            string(ptr1:ptr1)=' '
         else
            negative=.false.
         end if
         if (index(string,'-') .ne. 0) then
            call err_msg('hms2rad',
     $           'Only one minus sign may preceed RA')
            error=.true.
         else
            string=left_justify(string)
            ptr1=fnblnk(string)
            ptr2=index(string,' ')
            if (ptr1 .eq. 0) then
               call err_msg('hms2rad','The RA contains no number.')
               error=.true.
            else
               substring1=string(1:ptr2-1)
               string=left_justify(string(ptr2:))
               ptr1=fnblnk(string)
               ptr2=index(string,' ')
               if (ptr1 .eq. 0) then
                  substring2='0'
                  substring3='0'
               else
                  substring2=string(1:ptr2-1)
                  string=left_justify(string(ptr2:))
                  ptr1=fnblnk(string)
                  ptr2=index(string,' ')
                  if (ptr1 .eq. 0) then
                     substring3='0'
                  else
                     substring3=string(1:ptr2-1)
                     string=left_justify(string(ptr2:))
                     if (string .ne. ' ') then
                        call err_msg('hms2rad',
     $                       'Too many tokens in the RA string.')
                        error=.true.
                     end if
                  end if
               end if
            end if
         end if
      end if
      if (.not. error) then
         if ((is_fp_num(substring1) .or.
     $        is_int_num(substring1)) .and.
     $        (is_fp_num(substring2) .or.
     $        is_int_num(substring2)) .and.
     $        (is_fp_num(substring3) .or.
     $        is_int_num(substring3))) then
            if (is_int_num(substring1)) then
               read(substring1,*) idum
               rdum1=dble(idum)
            else
               read(substring1,*) rdum1
            end if
            if (is_int_num(substring2)) then
               read(substring2,*) idum
               rdum2=dble(idum)
            else
               read(substring2,*) rdum2
            end if
            if (is_int_num(substring3)) then
               read(substring3,*) idum
               rdum3=dble(idum)
            else
               read(substring3,*) rdum3
            end if
            if (rdum1 .lt. 24.0d0) then
               if (rdum2 .lt. 60.0d0) then
                  if (rdum3 .le. 60.0d0) then
                     rad=rdum3/3600.0d0+rdum2/60.0d0+rdum1
                     rad=pio180*rad*15.0d0
                     if (negative) then 
                        rad=-rad
                     end if
                  else
                     error=.true.
                     call err_msg('hms2rad',
     $                    'RA seconds must be less than 60.')
                  end if
               else
                  error=.true.
                  call err_msg('hms2rad',
     $                 'RA minutes must be less than 60.')
               end if
            else
               error=.true.
               call err_msg('hms2rad',
     $              'RA hours must be less than 24.')
            end if
         else
            call err_msg('hms2rad','The RA contains a non-number.')
            error=.true.
         end if
      end if
      if (error) then
         call err_msg('hms2rad','Traceback')
      end if
      return
      end

==> starnet.1.2.tar: hms2rad.f <==
      subroutine hms2rad(str,rad,error)
C
C $Id: hms2rad.f,v 1.4 1997/01/09 19:11:23 koehn Exp $
C
C Description:
C 
C This routine converts a string that specifies a Right Ascension in
C hour, minute, second format to an angle specified in radians.
C
C Programming interface:
C
C Name   In/out  Type           Structure  Meaning
C
C str    in      character*(*)  scalar     The string specifying the angle
C rad    out     real*8         scalar     The angle expressed in radians
C error  out     logical        scalar     TRUE if an error occurs.
C
C Errors:
C 
C If the angle is in a format that cannot be converted, or if the 
C string specification is in a non-standard format, or if the specified
C angle is out of the standard range, then error is
C set TRUE and the routine immediately terminates.
C
C Routines accessed:
C
C err_msg
C fnblnk
C is_fp_num
C is_int_num
C left_justify
C
      implicit none
      include 'std_io.f'
      include 'include_starnet.f'
      real*8 rad,rdum1,rdum2,rdum3
      integer ptr1,ptr2,fnblnk
      logical error,negative,is_fp_num,is_int_num
      character*64 string,substring1,substring2,substring3,
     $     left_justify
      character*(*) str
      rad=0.0d0
      string=str
      ptr1=fnblnk(string)
      if (ptr1 .eq. 0) then
         call err_msg('hms2rad','The RA string is empty.')
         error=.true.
      else
         if (string(ptr1:ptr1) .eq. '-') then
            negative=.true.
            string(ptr1:ptr1)=' '
         else
            negative=.false.
         end if
         if (index(string,'-') .ne. 0) then
            call err_msg('hms2rad',
     $           'Only one minus sign may preceed RA')
            error=.true.
         else
            string=left_justify(string)
            ptr1=fnblnk(string)
            ptr2=index(string,' ')
            if (ptr1 .eq. 0) then
               call err_msg('hms2rad','The RA contains no number.')
               error=.true.
            else
               substring1=string(1:ptr2-1)
               string=left_justify(string(ptr2:))
               ptr1=fnblnk(string)
               ptr2=index(string,' ')
               if (ptr1 .eq. 0) then
                  substring2='0'
                  substring3='0'
               else
                  substring2=string(1:ptr2-1)
                  string=left_justify(string(ptr2:))
                  ptr1=fnblnk(string)
                  ptr2=index(string,' ')
                  if (ptr1 .eq. 0) then
                     substring3='0'
                  else
                     substring3=string(1:ptr2-1)
                     string=left_justify(string(ptr2:))
                     if (string .ne. ' ') then
                        call err_msg('hms2rad',
     $                       'Too many tokens in the RA string.')
                        error=.true.
                     end if
                  end if
               end if
            end if
         end if
      end if
      if (.not. error) then
         if ((is_fp_num(substring1) .or.
     $        is_int_num(substring1)) .and.
     $        (is_fp_num(substring2) .or.
     $        is_int_num(substring2)) .and.
     $        (is_fp_num(substring3) .or.
     $        is_int_num(substring3))) then
            call str2r8(substring1,rdum1,error)
            if (error) goto 400
            call str2r8(substring2,rdum2,error)
            if (error) goto 400
            call str2r8(substring3,rdum3,error)
            if (error) goto 400
            if (rdum1 .lt. 24.0d0) then
               if (rdum2 .lt. 60.0d0) then
                  if (rdum3 .le. 60.0d0) then
                     rad=rdum3/3600.0d0+rdum2/60.0d0+rdum1
                     rad=pio180*rad*15.0d0
                     if (negative) then 
                        rad=-rad
                     end if
                  else
                     error=.true.
                     call err_msg('hms2rad',
     $                    'RA seconds must be less than 60.')
                  end if
               else
                  error=.true.
                  call err_msg('hms2rad',
     $                 'RA minutes must be less than 60.')
               end if
            else
               error=.true.
               call err_msg('hms2rad',
     $              'RA hours must be less than 24.')
            end if
         else
            call err_msg('hms2rad','The RA contains a non-number.')
            error=.true.
         end if
      end if
 400  continue
      if (error) then
         call err_msg('hms2rad','Traceback')
      end if
      return
      end
